// This is tbl/vipl/filter/vipl_filter_abs.cxx
#ifdef VCL_NEEDS_PRAGMA_INTERFACE
#pragma implementation
#endif
#include "vipl_filter_abs.h"
// the following is just for avoiding an empty library:
char dummy = 'p';
